@@ -37,6 +37,7 @@ _USER_NAME: str = 'USER_NAME'
 _ACCESS_TOKEN: str = 'ACCESS_TOKEN'
 _USER_ROLE: str = 'USER_ROLE'
 _CCF_SERVICES_HOST: str = 'CCF_SERVICES_HOST'
+_USER_S3_BUCKET: str = 'USER_S3_BUCKET'
 
 HEADERS = {
     'content-type': "application/json",
@@ -59,13 +60,14 @@ def connect():
         _access_token = os.getenv(_ACCESS_TOKEN, None)
         _user_role = os.getenv(_USER_ROLE, None)
         _ccf_services_host = os.getenv(_CCF_SERVICES_HOST, None)
+        _user_s3_bucket = os.getenv(_USER_S3_BUCKET, None)
         payload = json.dumps({"user_name": _user_name, "role_id": _user_role})
         r = requests.post(_ccf_services_host + API_VALIDATE_USER, data=payload, headers=HEADERS,
                           cookies=dict(sessionId=_access_token))
         response = r.json()
         if response[STATUS] == SUCCESS:
             athena_client = AthenaClient(user_name=_user_name, user_role=_user_role, access_token=_access_token,
-                                         ccf_services_host=_ccf_services_host)
+                                         ccf_services_host=_ccf_services_host, user_s3_bucket=_user_s3_bucket)
             return athena_client
         else:
             print(response[ERROR])
@@ -82,11 +84,12 @@ def connect():
 
 class AthenaClient:
 
-    def __init__(self, user_name, access_token, user_role, ccf_services_host):
+    def __init__(self, user_name, access_token, user_role, ccf_services_host, user_s3_bucket):
         self._user_name = user_name
         self._access_token = access_token
         self._user_role = user_role
         self._ccf_services_host = ccf_services_host
+        self._user_s3_bucket = user_s3_bucket
         print("Connection is successful...")
 
     def databases(self, result_as_df=True):
@@ -211,12 +214,12 @@ class AthenaClient:
         except requests.exceptions.RequestException:
             print("RequestException occurred")
 
-    def save_data(self, data, file_name, s3_bucket):
+    def save_data(self, data, file_name):
         """Returns records from a table"""
         try:
             d = data.to_dict(orient='records')
             payload = json.dumps({"user_name": self._user_name, "role_id": self._user_role, "file_name": file_name,
-                                  "s3_bucket": s3_bucket, "data": d})
+                                  "s3_bucket": self._user_s3_bucket, "data": d})
             r = requests.post(self._ccf_services_host + API_SAVE_DATA_TO_S3, data=payload, headers=HEADERS,
                               cookies=dict(sessionId=self._access_token))
             response = r.json()
